<?xml version="1.0" ?><!DOCTYPE TS><TS language="be" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Жыццё ёсць і вонках браўзера!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Версія %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Ліцэнзія на: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 ёсць свабодным праграмным забеспячэннем. Але яго развіццё займае каштоўны час.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Калі ласка, &lt;a href=&apos;%1&apos;&gt;ахвяруйце&lt;/a&gt; на падтрымку неперарыўнага развіцця %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Перакладайце %1 на родную мову праз %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Дызайн іконкі выканаў %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Выпушчана пад ліцэнзіяй &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыць</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Апісанне</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Увядзіце ліцэнзійныя звесткі</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Эл. пошта:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Код:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Набывайце ліцэнзію %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Тэрмін дэманстрацыі кончыўся.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Поўная версія дазволіць глядзець відэа бесперапынна.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Без ліцэнзіі праграма стане нядзейснай цераз %1 дзён.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Купляючы поўную версію, вы падтрымліваеце маю цяжкую працу па стварэнні %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Дэманстрацыя</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Ужыць ліцэнзію</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Набыць ліцэнзію</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Ад %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Усе відэа</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Нягледжаныя відэа</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>назвы</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>даты абнаўлення</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>даты дадання</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>даты апошняга прагляду</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>колькасці праглядаў</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Сартаваць паводле</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Пазначыць усё як гледжанае</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Паказаць абноўленыя</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Няма жаднай падпіскі. Ужывайце зорачку, каб падпісвацца на каналы.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Усе відэа</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Нягледжаныя відэа</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Пазначыць як гледжанае</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Адпісацца</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Падпіскі пакуль не абнаўляліся.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 праглядаў</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>байтаў</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>КБ</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>МБ</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>Б/с</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>КБ/с</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>МБ/с</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>секундаў</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>хвілін</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 да канца</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 сцягнута ў %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Сцягванне завершана</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Змяніць размяшчэнне...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Размяшчэнне сцягнутага</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Размяшчэнне сцягнутага абноўлена.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Бягучыя сцягванні запішуцца ў ранейшае месца.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Сцягваецца ў: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Сцягванні</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reinstall</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Граць</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Паўза</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Граць/Паўза</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Спыніць</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Спыніцца пасля бягучага трэка</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Наступны трэк</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Папярэдні трэк</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Гучней</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Цішэй</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Бязгучна</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Праматаць наперад</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Праматаць назад</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Шукаць відэа і каналы з ключавымі словамі</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Агляд</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Аглядаць відэа паводле катэгорыі</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Падпіскі</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Падпіскі на каналы</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Пачуйцеся выгодна</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Памылка</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Акно</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Згарнуць</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Спыніць</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Спыніць прайграванне і вярнуцца да пошуку</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>Папя&amp;рэдні</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Вярнуцца да папярэдняга трэка</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>П&amp;рапусціць</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Перайсці да наступнага відэа</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Граць</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Аднавіць прайграванне</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Поўны &amp;экран</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Уключыць на поўны экран</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Кампактны рэжым</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Схаваць плэйліст і панель інструментаў</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Адкрыць старонку на &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Перайсці на старонку YouTube і паставіць на паўзу</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Скапіяваць YouTube-&amp;спасылку</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Скапіяваць YouTube-спасылку бягучага відэа ў буфер</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Скапіяваць спасылку на відэа&amp;паток</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Скапіяваць спасылку на бягучы відаэпаток у буфер</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Знайсці &amp;часткі відэа</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Знайсці іншыя часці відэа, імаверна, у правільным парадку</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Вы&amp;даліць</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Выдаліць абраныя відэа з плэйлісту</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Пасунуць у&amp;верх</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Пасунуць абраныя відэа ўверх па плэйлісце</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Пасунуць у&amp;ніз</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Пасунуць абраныя відэа ўніз па плэйлісце</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>А&amp;чысціць апошнія запытанні</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Ачысціць гісторыю пошуку. Няможна адкаціць.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выйсці</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Бывай</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Вэб-сайт</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 у інтэрнеце</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>&amp;Ахвяраваць</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Калі ласка, падтрымайце развіццё %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Апісанне</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Звесткі пра %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Бязгучна</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Пачынаць &amp;гранне ўручную</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Пачынаць граць відэа ўручную</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Сцягванні</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Падрабязнасці пра сцягванні</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Сцягнуць</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Сцягнуць бягучае відэа</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Зрабіць &amp;здымак</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Падпісацца на канал</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Распаўсюдзіць відэа праз %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Пошта</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Пошта</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыць</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Заставацца па-над усімі вокнамі</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Спыніцца пасля гэтага відэа</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Паведаміць пра хібу...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>У&amp;дасканаліць запытанне...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Больш...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Падобныя відэа</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Глядзець відэа, падобныя да гэтага</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Адкрыць у &amp;браўзеры...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Падабаецца %1? Ацані яго!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Купіць %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Праграма</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Прайграванне</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Плэй&amp;ліст</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Відэа</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Распаўсюд</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Выгляд</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Дапамога</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Націсніце %1 для павелічэння гуку, %2 для памяншэння</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Выберыце вашае месцаразмяшчэнне</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1 адкрываецца</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Жадаеце выйсці з %1 маючы актыўныя сцягванні?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Калі зараз выйсці з %1, яны будуць скасаваныя.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Закрыць і скасаваць сцягванне</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Прычакаць сканчэння сцягвання</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Памылка: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Паўза</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Паставіць на паўзу</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Пакінуць поўна&amp;экранны рэжым</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Засталося: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Гучнасць: %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Гуку няма</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Гук ёсць</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Максімальны памер відэа: %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Вашая прыватнасць цяпер у бяспецы</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Сцягванне завершанае</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 версіі %2 ужо даступны.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Напомніць пазней</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Абнаўленне</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Цяпер можна ўставіць YouTube-спасылку ў іншую праграму</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Цяпер можна ўстаўляць спасылкі на відэапаток у іншых праграмах</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Спасылка будзе заставацца слушнай абмежаваны час.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Сцягваецца %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>з</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>часць</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>эпізод</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Адпраўлена з %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Адпісацца ад %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Падпісацца на %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Даступна новая версія %1!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>Ужо даступны %1 %2. У вас — %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Сцягнуць зараз?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Прапусціць гэтую версію</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Напомніць пазней</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Устанавіць абнаўленне</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Уставіць</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 з %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Падрыхтоўка</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Памылка</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Завершана</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Спынена</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Спыніць сцягванне</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Паказаць у %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Адчыніць бацькоўскую папку</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Перазапусціць сцягванне</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Паказаць яшчэ %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Няма відэа</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Больш няма відэа</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Сартаваць паводле</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>адпаведнасці</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>даты</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>колькасці праглядаў</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>ацэнак</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>За ўвесь час</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Сёння</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 дзён</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 дзён</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Працягласць</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Усе</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Кароткія</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Сярэднія</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Даўгія</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Меншыя за 4 хвіліны</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>4—20 хвілін</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Даўжэйшыя за 20 хвілін</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Якасць</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>High Definition</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p і лепей</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Гатова</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Гатова</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Ласкава запрашаем у &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>, каб пачаць глядзець відэа.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>ключавое слова</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Задайце</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Апошнія запытанні</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Апошнія каналы</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Атрымаць поўную версію</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Наперад да %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Назад да %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Удасканаліць запытанне</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Мелі на ўвазе: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Змяніць размяшчэнне...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Здымак захаваны ў %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Размяшчэнне здымкаў зменена.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Папулярныя</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Сцягваецца абнаўленне...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Алжыр</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Аргентына</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Аўстралія</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Бельгія</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Бразілія</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Канада</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Чылі</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Калумбія</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Чэхія</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Егіпет</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Францыя</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Нямеччына</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Гана</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Грэцыя</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Ганконг</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Вугоршчына</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Індыя</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Інданезія</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Ірландыя</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Ізраіль</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Італія</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Японія</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Іардан</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Кенія</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Малайзія</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Мексіка</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Марока</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Нідэрланды</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Новая Зеландыя</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Нігерыя</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Перу</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Філіпіны</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Польшча</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Расія</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Саудаўская Аравія</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Сінгапур</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Паўднёвая Афрыка</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Паўднёвая Карэя</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Гішпанія</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Шведыя</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Тайвань</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Туніс</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Турцыя</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Уганда</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Аб&apos;яднаныя Арабскія Эміраты</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Вялікая Брытанія</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Емен</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Увесь свет</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Не ўдалося атрымаць відэа-паток для %1</translation>
    </message>
</context>
</TS>